<?php
/*** COPYRIGHT NOTICE *********************************************************
 *
 * Copyright 2009-2017 ProjeQtOr - Pascal BERNARD - support@projeqtor.org
 * Contributors : -
 *
 * This file is part of ProjeQtOr.
 * 
 * ProjeQtOr is free software: you can redistribute it and/or modify it under 
 * the terms of the GNU Affero General Public License as published by the Free 
 * Software Foundation, either version 3 of the License, or (at your option) 
 * any later version.
 * 
 * ProjeQtOr is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for 
 * more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * ProjeQtOr. If not, see <http://www.gnu.org/licenses/>.
 *
 * You can get complete code of ProjeQtOr, other resource, help and information
 * about contributors at http://www.projeqtor.org 
 *     
 *** DO NOT REMOVE THIS NOTICE ************************************************/

require_once('_securityCheck.php');
class WorkCommand extends SqlElement {
    
    public $_sec_Description;
	public $id;
	public $idProject;
	public $idCommand;
	public $idWorkUnit;
	public $idComplexity;
	public $name;
	public $unitAmount;
	public $_tab_2_3 = array('ShortQuantity','amount', 'Ordered', 'Realised', 'IsBilled');
	public $commandQuantity;
	public $commandAmount;
	public $doneQuantity;
	public $doneAmount;
	public $billedQuantity;
	public $billedAmount;
	public $idle;
	public $_sec_Link;
	public $_Link = array();
	public $_Attachment = array();
	public $_Note = array();
	public $_nbColMax = 3;
	
	private static $_fieldsAttributes=array(
	    "idProject"=>"required, doNotAutoFill",
	    "idWorkUnit"=>"required",
	    "idComplexity"=>"required",
	    "name"=>"readonly",
	    "commandAmount"=>"readonly",
	    "doneAmount"=>"readonly",
	    "billedAmount"=>"readonly",
	    "unitAmount"=>"hidden",
	    "idle"=>"hidden",
	    "commandQuantity"=>"smallWidth,size1/2",
	    "doneQuantity"=>"readonly,smallWidth,size1/2",
	    "billedQuantity"=>"readonly,smallWidth,size1/2",
	);
	
	private static $_layout='
      <th field="id" formatter="numericFormatter" width="5%"># ${id}</th>
	  <th field="idCommand" width="7%" >${idCommand}</th>
	  <th field="name" width="35%" >${name}</th>
	  <th field="commandQuantity" formatter="numericFormatter" width="12%">${commandQuantity}</th>
	  <th field="commandAmount" formatter="costFormatter" width="12%">${commandAmount}</th> 
	  <th field="doneQuantity" formatter="numericFormatter" width="12%">${doneQuantity}</th>
	  <th field="doneAmount" formatter="costFormatter" width="12%">${doneAmount}</th>  
    ';
	
	private static $_colCaptionTransposition = array(
	    "idCommand"=>"command",
	);
	
	/** ==========================================================================
	 * Construct
	 * @return void
	 */
	function __construct($id = NULL, $withoutDependentObjects=false) {
	  parent::__construct($id,$withoutDependentObjects);
	  //$this->idCommand=2;
	}
	
	/** ==========================================================================
	 * Destructor
	 * @return void
	 */
	function __destruct() {
	  parent::__destruct();
	}
	
	/** ==========================================================================
	 * Return the specific fieldsAttributes
	 * @return Array the fieldsAttributes
	 */
	protected function getStaticFieldsAttributes() {
	  return self::$_fieldsAttributes;
	}
	
	/** ==========================================================================
	 * Return the specific layout
	 * @return String the layout
	 */
	protected function getStaticLayout() {
	  return self::$_layout;
	}
	
	/** ============================================================================
	 * Return the specific colCaptionTransposition
	 * @return String the colCaptionTransposition
	 */
	protected function getStaticColCaptionTransposition($fld=null) {
	  return self::$_colCaptionTransposition;
	}
	
	/**=========================================================================
	 * Overrides SqlElement::save() function to add specific treatments
	 * @see persistence/SqlElement#save()
	 * @return String the return message of persistence/SqlElement#save() method
	 */
	public function save() {
	  if (!$this->idProject) {
	    $workunit = new WorkUnit($this->idWorkUnit);
	    $this->idProject=$workunit->idProject;
	  }
	  $valComplexity = new ComplexityValues();
	  $price=0;
      $listValComplexity = $valComplexity->getSqlElementsFromCriteria(array('idComplexity'=>$this->idComplexity,'idWorkUnit'=>$this->idWorkUnit));
      foreach ($listValComplexity as $item){
        $price = $item->price;
      }
      $this->unitAmount = $price;
      $this->commandAmount = $this->unitAmount * $this->commandQuantity;
      $this->doneAmount = $this->unitAmount * $this->doneQuantity;
      $this->billedAmount = $this->unitAmount * $this->billedQuantity;
	  $result = parent::save();
	  return $result;
	}
	
	public function setAttributes(){
	  if($this->idProject) self::$_fieldsAttributes ['idProject'] = 'readonly';
	}
	
	public function simpleSave($withoutDependencies=false) {
	  return parent::saveForced($withoutDependencies);
	}
	
	public function deleteControl(){
	  $result="";
	   
	  // Cannot delete done WorkCommand
	  if ($this->doneQuantity and $this->doneQuantity > 0 )	{
	    $result .= "<br/>" . i18n("errorDeleteDoneWorkCommand");
	  }
	  // Cannot delete billed WorkCommand
	  if ($this->billedQuantity and $this->billedQuantity > 0 )	{
	    $result .= "<br/>" . i18n("errorDeleteBilledWorkCommand");
	  }
	
	  if (! $result) {
	    $result=parent::deleteControl();
	  }
	  return $result;
	}
	
	private static $_databaseCriteria = array();   
	
	/** ========================================================================
	 * Return the specific database criteria
	 * @return String the databaseTableName
	 */
	protected function getStaticDatabaseCriteria() {
	  return self::$_databaseCriteria;
	}
			
    public function getValidationScript($colName) {
      $colScript = parent::getValidationScript ( $colName );
      if ($colName=="idProject") {
        $colScript .= '<script type="dojo/connect" event="onChange" >';
        $colScript .= '  if (this.value) {';
        $colScript .= '    dijit.byId("idWorkUnit").set("value",null);';
        $colScript .= '    refreshList("idWorkUnit","idProject", this.value, null, null, true);';
        $colScript .= '  } else {';
        $colScript .= '    refreshList("idWorkUnit","idProject", null, null, null, true);';
        $colScript .= '  }';
		$colScript .= '</script>';
      }else if ($colName=="idWorkUnit") {
        $colScript .= '<script type="dojo/connect" event="onChange" >';
        $colScript .= '  if (this.value) {';
        $colScript .= '    dijit.byId("idComplexity").set("value",null);';
        $colScript .= '    var idWorkUnit = dijit.byId("idWorkUnit").get("value");';
        $colScript .= '    refreshList("idComplexity","idWorkUnit", idWorkUnit, null, null, true);';
        $colScript .= '  }';
        $colScript .= '</script>';         
      }
       if ($colName=="idWorkUnit" || $colName=="idComplexity") {
        $colScript .= '<script type="dojo/connect" event="onChange" >';
        $colScript .= '  var idWorkUnit = dojo.byId("idWorkUnit").value;';
        $colScript .= '  var idComplexity = dojo.byId("idComplexity").value;';
        $colScript .= '  var nameConcatenated = idWorkUnit + " - " + idComplexity;';
        $colScript .= '  dojo.byId("name").value = nameConcatenated;';
        $colScript .= '  terminateChange();';
        $colScript .= '  formChanged();';
        $colScript .= '</script>';
      }
      return $colScript;
    }
}